@@ -196,9 +196,9 @@ as.neuronlistfh.neuronlist<-function(x, df=attr(x,'df'), dbdir=NULL,
     names(x)=seq(x)
   }
   WriteObjects=match.arg(WriteObjects)
+  dbClass=match.arg(dbClass)
   if(WriteObjects!='yes' && dbClass!='RDS')
     stop("Must always write objects when dbClass!='RDS'")
-  dbClass=match.arg(dbClass)
   if(dbClass!='RDS' && !is.null(remote))
     stop("remote download only implemented for RDS class at the moment")
   # md5 by default. Should we use something else?
@@ -249,16 +249,9 @@ as.neuronlist.neuronlistfh<-function(l, ...){
     return(attr(x,'db')[[i,...]])
   }
   
-  # The tryCatch block below will leak a connection, so make a note of how many
-  # we start with so we can remove the extra one once the block has finished
-  connBefore <- rownames(showConnections(all=T))
-  
-  # we have a remote. let's try and use it to fetch these keys
   tryCatch({
-    # DEBUG: The leak happens here
-    attr(x,'db')[[i,...]]
+    attr(x, 'db')[[i, ...]]
   }, error = function(e) {
-    # DEBUG: We'll have an extra connection now
     fillMissing(i, x)
     tryCatch({
       attr(x, 'db')[[i, ...]]
@@ -266,12 +259,6 @@ as.neuronlist.neuronlistfh<-function(l, ...){
       "Unable to download file."
       stop(e)
     })
-  }, finally = {
-    # Deal with connection leak
-    connAfter <- rownames(showConnections(all=T))
-    connNew <- setdiff(connAfter,connBefore)
-    if(length(connNew) > 0)
-      close(getConnection(as.integer(connNew)))
   })
 }
 
