@@ -2,11 +2,11 @@ context("npop3d")
 
 test_that("pop last plotted neurons",{
   nopen3d()
-  original.rgl.ids=rgl.ids()
+  original.rgl.ids=ids3d()
   plot3d(c("EBH11R", "EBH20L"), db=Cell07PNs)
   npop3d()
-  expect_equal(rgl.ids(), original.rgl.ids)
-  rgl.close()
+  expect_equal(ids3d(), original.rgl.ids)
+  close3d()
 })
 
 context("nview3d")
